==> postgresql-2024.2.92+6b985e51b.tgz: postgresql/CHANGELOG.md <==
# Release notes

## 2024.2.0-40

- 0.1.0 Initial Chart
- 0.1.1 Change helm-toolkit dependency version to ">= 0.1.0"
- 0.1.2 adding archiving to postgres
- 0.1.3 Use explicit entrypoint for prometheus exporter
- 0.1.4 Allow probe tweaking
- 0.1.5 Optimize restart behavior
- 0.1.6 Revert "Add default reject rule ..."
- 0.1.7 postgres archive cleanup script
- 0.1.8 Add tls to Postgresql
- 0.1.9 Use full image ref for docker official images
- 0.1.10 Helm 3 - Fix Job labels
- 0.1.11 Update htk requirements
- 0.1.12 Enhance postgresql backup
- 0.1.13 Remove set -x
- 0.1.14 Fix invalid fields in values
- 0.1.15 Migrated CronJob resource to batch/v1 API version
- 0.1.16 Added OCI registry authentication
- 0.1.17 Added empty verify_databases_backup_archives() function implementation to match updated backup_databases() function in helm-toolkit
- 0.1.18 Updated postgres to 14.5 and replaced deprecated config item wal_keep_segments with wal_keep_size
- 0.1.19 Added staggered backups support
- 0.1.20 Added throttling remote backups
- 0.1.21 Use quay.io/airshipit/kubernetes-entrypoint:latest-ubuntu_focal by default
- 0.1.22 Update default images tags. Add 2024.1-ubuntu_jammy overrides.
- 0.1.23 Add 2024.2 overrides
- 0.1.24 Update Chart.yaml apiVersion to v2
- 2024.2.0 Update version to align with the Openstack release cycle

## 2024.2.0

Before 2024.2.0 all the OpenStack-Helm charts were versioned independently.
Here we provide all the release notes for the chart for all versions before 2024.2.0.

==> postgresql-2025.1.3+35052e51b.tgz: postgresql/CHANGELOG.md <==
# Release notes

## 2025.1.0-83

- Add support of hostPath volume for archive mode
- Use DirectoryOrCreate type for hostPath volumes

### New Features

- Update apparmor values to use security_context instead of annotations.
- Add support for runtimeClassName and priorityClassName

## 2025.1.0

- 0.1.0 Initial Chart
- 0.1.1 Change helm-toolkit dependency version to ">= 0.1.0"
- 0.1.2 adding archiving to postgres
- 0.1.3 Use explicit entrypoint for prometheus exporter
- 0.1.4 Allow probe tweaking
- 0.1.5 Optimize restart behavior
- 0.1.6 Revert "Add default reject rule ..."
- 0.1.7 postgres archive cleanup script
- 0.1.8 Add tls to Postgresql
- 0.1.9 Use full image ref for docker official images
- 0.1.10 Helm 3 - Fix Job labels
- 0.1.11 Update htk requirements
- 0.1.12 Enhance postgresql backup
- 0.1.13 Remove set -x
- 0.1.14 Fix invalid fields in values
- 0.1.15 Migrated CronJob resource to batch/v1 API version
- 0.1.16 Added OCI registry authentication
- 0.1.17 Added empty verify_databases_backup_archives() function implementation to match updated backup_databases() function in helm-toolkit
- 0.1.18 Updated postgres to 14.5 and replaced deprecated config item wal_keep_segments with wal_keep_size
- 0.1.19 Added staggered backups support
- 0.1.20 Added throttling remote backups
- 0.1.21 Use quay.io/airshipit/kubernetes-entrypoint:latest-ubuntu_focal by default
- 0.1.22 Update default images tags. Add 2024.1-ubuntu_jammy overrides.
- 0.1.23 Add 2024.2 overrides
- 0.1.24 Update Chart.yaml apiVersion to v2
- 2024.2.0 Update version to align with the Openstack release cycle

## 2024.2.0

Before 2024.2.0 all the OpenStack-Helm charts were versioned independently.
Here we provide all the release notes for the chart for all versions before 2024.2.0.
